#
# spec file for package python-PyInstaller
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-PyInstaller
Version:        3.2.1
Release:        1.11
Summary:        PyInstaller bundles a Python app (inc. dependencies) into a single package
License:        GPL-2.0+
Group:          Development/Languages/Python3
Url:            http://www.pyinstaller.org
Source0:        https://files.pythonhosted.org/packages/source/P/PyInstaller/PyInstaller-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  python3-Sphinx
BuildRequires:  python3-setuptools
BuildRequires:  zlib-devel
Requires(post): update-alternatives
Requires(preun): update-alternatives
BuildRoot: %{_tmppath}/PyInstaller-%{version}-%{release}-buildroot

%description
PyInstaller bundles a Python application and all its dependencies into a single
package. The user can run the packaged app without installing a Python
interpreter or any modules.

%prep
%setup -q -n PyInstaller-%{version}

%build
rm -rf PyInstaller/bootloader/*-*
cd bootloader
python3 ./waf --no-lsb distclean all
cd ..
python3 setup.py build
# build docs
cd doc && make html && rm _build/html/.buildinfo

%install
python3 setup.py install --prefix="%{_prefix}" --root=%{buildroot}
%fdupes -s %{buildroot}/%{python3_sitelib}

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives

for f in pyi-makespec pyinstaller ; do
    install -D -m 0644 doc/${f}.1 %{buildroot}/%{_mandir}/man1/${f}.1
    gzip %{buildroot}/%{_mandir}/man1/${f}.1
    mv %{buildroot}/%{_mandir}/man1/${f}.1.gz %{buildroot}/%{_mandir}/man1/${f}-%{py3_ver}.1.gz
    ln -s -f %{_sysconfdir}/alternatives/${f}.1.gz %{buildroot}%{_mandir}/man1/${f}.1.gz
    # create a dummy target for /etc/alternatives/${f}.1.gz
    touch %{buildroot}%{_sysconfdir}/alternatives/${f}.1.gz
    rm doc/${f}.1
done

binaries="pyi-archive_viewer pyi-bindepend pyi-grab_version pyi-makespec pyi-set_version pyinstaller"
for p in $binaries; do
    mv %{buildroot}%{_bindir}/$p %{buildroot}%{_bindir}/$p-%{py3_ver}
    ln -s -f %{_sysconfdir}/alternatives/$p %{buildroot}%{_bindir}/$p
    # create a dummy target for /etc/alternatives/$p
    touch %{buildroot}%{_sysconfdir}/alternatives/$p
done

%post
%_sbindir/update-alternatives \
    --install %{_bindir}/pyinstaller pyinstaller %{_bindir}/pyinstaller-%{py3_ver} 30 \
    --slave %{_bindir}/pyi-archive_viewer pyi-archive_viewer %{_bindir}/pyi-archive_viewer-%{py3_ver} \
    --slave %{_bindir}/pyi-bindepend pyi-bindepend %{_bindir}/pyi-bindepend-%{py3_ver} \
    --slave %{_bindir}/pyi-grab_version pyi-grab_version %{_bindir}/pyi-grab_version-%{py3_ver} \
    --slave %{_bindir}/pyi-makespec pyi-makespec %{_bindir}/pyi-makespec-%{py3_ver} \
    --slave %{_bindir}/pyi-set_version pyi-set_version %{_bindir}/pyi-set_version-%{py3_ver} 

%preun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove pyinstaller %{_bindir}/pyinstaller-%{py3_ver}
fi

%files
%defattr(-,root,root)
%doc README.rst
%doc doc/_build/html
%{_mandir}/man1/*
%{_bindir}/pyi-archive_viewer
%{_bindir}/pyi-bindepend
%{_bindir}/pyi-grab_version
%{_bindir}/pyi-makespec
%{_bindir}/pyi-set_version
%{_bindir}/pyinstaller
%{_bindir}/pyi-archive_viewer-%{py3_ver}
%{_bindir}/pyi-bindepend-%{py3_ver}
%{_bindir}/pyi-grab_version-%{py3_ver}
%{_bindir}/pyi-makespec-%{py3_ver}
%{_bindir}/pyi-set_version-%{py3_ver}
%{_bindir}/pyinstaller-%{py3_ver}
%ghost %{_sysconfdir}/alternatives/pyi-archive_viewer
%ghost %{_sysconfdir}/alternatives/pyi-bindepend
%ghost %{_sysconfdir}/alternatives/pyi-grab_version
%ghost %{_sysconfdir}/alternatives/pyi-makespec
%ghost %{_sysconfdir}/alternatives/pyi-set_version
%ghost %{_sysconfdir}/alternatives/pyinstaller
%ghost %{_sysconfdir}/alternatives/pyi-makespec.1.gz
%ghost %{_sysconfdir}/alternatives/pyinstaller.1.gz
%{python3_sitelib}/*

%changelog
* Mon Jan 23 2017 termim@gmail.com
- use update-alternatives
- update to 3.2.1
  * New, updated and fixed hooks: botocore (#2094), gi (#2347), jira (#2222),
    PyQt5.QtWebEngineWidgets (#2269), skimage (#2195, 2225), sphinx (#2323,)
    xsge_gui (#2251).
  * Don't fail if working directory already exists (#1994)
  * Avoid encoding errors in main script (#1976)
  * Fix hasher digest bytes not str (#2229, #2230)
  * (Windows) Fix additional dependency on the msvcrt10.dll (#1974)
  * (Windows) Correctly decode a bytes object produced by pefile (#1981)
  * (Windows) Package ``pefile`` with pyinstaller.  This partially
    undoes some changes in 3.2 in which the packaged pefiles were
    removed to use the pypi version instead.  The pypi version was
    considerably slower in some applications, and still has a couple
    of small issues on PY3. (#1920)
  * (OS X) PyQt5 packaging issues on MacOS (#1874)
  * (OS X) Replace run-time search path keyword (#1965)
  * (OS X) (Re-) add argv emulation for OSX, 64-bit (#2219)
  * (OS X) use decode("utf-8") to convert bytes in getImports_macholib() (#1973)
  * (Bootloader) fix segfaults (#2176)
  * (setup.py) pass option --no-lsb on GNU/Linux only (#1975)
  * Updates and fixes in documentation, manuals, et al. (#1986, 2002, #2153,
    [#2227], #2231)
* Mon Jul 11 2016 arun@gmx.de
- specfile:
  * use Sphinx to build doc section
  * shortened summary
- update to version 3.2:
  * Even the “main” script is now byte-compiled (#1847, #1856)
  * The manual is on readthedocs.io now (#1578)
  * On installation try to compile the bootloader if there is none for
    the current plattform (#1377)
  * (Unix) Use objcopy to create a valid ELF file (#1812, #1831)
  * (Linux): Compile with _FORTIFY_SOURCE (#1820)
  * New, updated and fixed hooks: CherryPy (#1860), Cryptography
    (#1425, #1861), enchant (1562), gi.repository.GdkPixbuf (#1843),
    gst (#1963), Lib2to3 (#1768), PyQt4, PyQt5, PySide (#1783, #1897,
    [#1887]), SciPy (#1908, #1909), sphinx (#1911, #1912), sqlalchemy
    (#1951), traitlets wx.lib.pubsub (#1837, #1838),
  * For windowed mode add isatty() for our dummy NullWriter (#1883)
  * Suppress “Failed to execute script” in case of SystemExit (#1869)
  * Do not apply Upx compressor for bootloader files (#1863)
  * Fix absolute path for lib used via ctypes (#1934)
  * (OSX) Fix binary cache on NFS (#1573, #1849)
  * (Windows) Fix message in grab_version (#1923)
  * (Windows) Fix wrong icon paramter in Windows example (#1764)
  * (Windows) Fix win32 unicode handling (#1878)
  * (Windows) Fix unnecessary rebuilds caused by rebuilding
    winmanifest (#1933)
  * (Cygwin) Fix finding the Python library for Cygwin 64-bit (#1307,
    [#1810], #1811)
  * (OSX) Fix compilation issue (#1882)
  * (Windows) No longer bundle pefile, use package from for windows
    (#1357)
  * (Windows) Provide a more robust means of executing a Python script
  * AIX fixes.
  * Update waf to version 1.8.20 (#1868)
  * Fix excludedimports, more predictable order how hooks are applied
    [#1651]
  * Internal impovements and code clean-up (#1754, #1760, #1794,
    [#1858], #1862, #1887, #1907, #1913)
  * Clean-ups fixes and improvements for the test suite
  * Known Issues
    + Apps built with Windows 10 and Python 3.5 may not run on Windows
    versions earlier than 10 (#1566).
    + The multipackage (MERGE) feature (#1527) is currently broken.
    + (OSX) Support for OpenDocument events (#1309) is broken.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Mon Feb  1 2016 arun@gmx.de
- specfile:
  * updated source url to point to pypi
- updated to version 3.1.1:
  * Fix problems with setuptools 19.4 (#1772, #1773, #1790, #1791)
  * 3.1 does not collect certain direct imports (#1780)
  * Git reports wrong version even if on unchanged release (#1778)
  * Don’t resolve symlinks in modulegraph.py (#1750, #1755)
  * ShortFileName not returned in win32 util (#1799)
* Sat Jan 16 2016 termim@gmail.com
- Initial check in v3.1
